@@ -81,8 +81,8 @@ module.exports = [
   ['a****c**?**??*****', ['abcdecdhjk'], null, ['abcdecdhjk']],
   ['[-abc]', ['-'], null, ['-']],
   ['[abc-]', ['-'], null, ['-']],
-  ['\\', ['\\'], null, ['\\']],
-  ['[\\\\]', ['\\'], null, ['\\']],
+  ['\\', ['\\'], null, ['\\'], { skip: process.platform === 'win32' }],
+  ['[\\\\]', ['\\'], null, ['\\'], { skip: process.platform === 'win32' }],
   ['[[]', ['['], null, ['[']],
   ['[', ['['], null, ['[']],
   ['[*', ['[abc'], null, ['[abc']],
@@ -175,7 +175,8 @@ module.exports = [
     '+(a|*\\|c\\\\|d\\\\\\|e\\\\\\\\|f\\\\\\\\\\|g',
     ['+(a|b\\|c\\\\|d\\\\|e\\\\\\\\|f\\\\\\\\|g'],
     {},
-    ['+(a|b\\|c\\\\|d\\\\|e\\\\\\\\|f\\\\\\\\|g', 'a', 'b\\c']
+    ['+(a|b\\|c\\\\|d\\\\|e\\\\\\\\|f\\\\\\\\|g', 'a', 'b\\c'],
+    {skip: process.platform === 'win32'},
   ],
 
   // crazy nested {,,} and *(||) tests.
@@ -256,6 +257,8 @@ module.exports = [
     ]
   ],
 
+  ['**/.x/**', ['a/.x/b'], {noglobstar: true}],
+
   'https://github.com/isaacs/minimatch/issues/59',
   ['[z-a]', []],
   ['a/[2015-03-10T00:23:08.647Z]/z', []],
@@ -265,106 +268,6 @@ module.exports = [
   ['# ignore this', []],
 ]
 
-module.exports.regexps = [
-  '/^(?:(?=.)a[^/]*?)$/',
-  '/^(?:(?=.)X[^/]*?)$/',
-  '/^(?:(?=.)X[^/]*?)$/',
-  '/^(?:\\*)$/',
-  '/^(?:(?=.)\\*[^/]*?)$/',
-  '/^(?:\\*\\*)$/',
-  '/^(?:(?=.)b[^/]*?\\/)$/',
-  '/^(?:(?=.)c[^/]*?)$/',
-  '/^(?:(?:(?!(?:\\/|^)\\.).)*?)$/',
-  '/^(?:\\.\\.\\/(?!\\.)(?=.)[^/]*?\\/)$/',
-  '/^(?:s\\/(?=.)\\.\\.[^/]*?\\/)$/',
-  '/^(?:\\/\\^root:\\/\\{s\\/(?=.)\\^[^:][^/]*?:[^:][^/]*?:\\([^:]\\)[^/]*?\\.[^/]*?\\$\\/1\\/)$/',
-  '/^(?:\\/\\^root:\\/\\{s\\/(?=.)\\^[^:][^/]*?:[^:][^/]*?:\\([^:]\\)[^/]*?\\.[^/]*?\\$\\/\u0001\\/)$/',
-  '/^(?:(?!\\.)(?=.)[a-c]b[^/]*?)$/',
-  '/^(?:(?!\\.)(?=.)[a-y][^/]*?[^c])$/',
-  '/^(?:(?=.)a[^/]*?[^c])$/',
-  '/^(?:(?=.)a[X-]b)$/',
-  '/^(?:(?!\\.)(?=.)[^a-c][^/]*?)$/',
-  '/^(?:a\\*b\\/(?!\\.)(?=.)[^/]*?)$/',
-  '/^(?:(?=.)a\\*[^/]\\/(?!\\.)(?=.)[^/]*?)$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?\\\\\\![^/]*?)$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?\\![^/]*?)$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?\\.\\*)$/',
-  '/^(?:(?=.)a[b]c)$/',
-  '/^(?:(?=.)a[b]c)$/',
-  '/^(?:(?=.)a[^/]c)$/',
-  '/^(?:a\\*c)$/',
-  'false',
-  '/^(?:(?!\\.)(?=.)[^/]*?\\/(?=.)man[^/]*?\\/(?=.)bash\\.[^/]*?)$/',
-  '/^(?:man\\/man1\\/bash\\.1)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/]*?c)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]c)$/',
-  '/^(?:(?!\\.)(?=.)[^/][^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/][^/])$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/][^/])$/',
-  '/^(?:(?!\\.)(?=.)[^/][^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]c)$/',
-  '/^(?:(?!\\.)(?=.)[^/][^/]*?[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/]*?[^/]*?c)$/',
-  '/^(?:(?!\\.)(?=.)[^/][^/]*?[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/]*?[^/]*?[^/])$/',
-  '/^(?:(?!\\.)(?=.)[^/][^/]*?[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/]*?[^/]*?)$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?c)$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/])$/',
-  '/^(?:(?=.)a[^/]*?cd[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/][^/]k)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/][^/]*?[^/]*?cd[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/][^/]k)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/][^/]*?[^/]*?cd[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/][^/]k[^/]*?[^/]*?[^/]*?)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/][^/]*?[^/]*?cd[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/][^/][^/]*?[^/]*?[^/]*?k)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/][^/]*?[^/]*?cd[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/][^/][^/]*?[^/]*?[^/]*?k[^/]*?[^/]*?)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/]*?[^/]*?c[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/][^/][^/]*?[^/]*?[^/]*?[^/]*?[^/]*?)$/',
-  '/^(?:(?!\\.)(?=.)[-abc])$/',
-  '/^(?:(?!\\.)(?=.)[abc-])$/',
-  '/^(?:\\\\)$/',
-  '/^(?:(?!\\.)(?=.)[\\\\])$/',
-  '/^(?:(?!\\.)(?=.)[\\[])$/',
-  '/^(?:\\[)$/',
-  '/^(?:(?=.)\\[(?!\\.)(?=.)[^/]*?)$/',
-  '/^(?:(?!\\.)(?=.)[\\]])$/',
-  '/^(?:(?!\\.)(?=.)[\\]-])$/',
-  '/^(?:(?!\\.)(?=.)[a-z])$/',
-  '/^(?:(?!\\.)(?=.)[^/][^/][^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/]*?[^/]*?[^/])$/',
-  '/^(?:(?!\\.)(?=.)[^/][^/][^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/]*?[^/]*?c)$/',
-  '/^(?:(?!\\.)(?=.)[^/][^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?c[^/]*?[^/]*?[^/]*?[^/]*?[^/][^/]*?[^/]*?[^/]*?[^/]*?)$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?c[^/]*?[^/][^/]*?[^/]*?)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?c[^/]*?[^/][^/]*?[^/]*?)$/',
-  '/^(?:(?=.)a[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/][^/][^/][^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?[^/]*?)$/',
-  '/^(?:\\[\\])$/',
-  '/^(?:\\[abc)$/',
-  '/^(?:(?=.)XYZ)$/i',
-  '/^(?:(?=.)ab[^/]*?)$/i',
-  '/^(?:(?!\\.)(?=.)[ia][^/][ck])$/i',
-  '/^(?:\\/(?!\\.)(?=.)[^/]*?|(?!\\.)(?=.)[^/]*?)$/',
-  '/^(?:\\/(?!\\.)(?=.)[^/]|(?!\\.)(?=.)[^/]*?)$/',
-  '/^(?:(?:(?!(?:\\/|^)\\.).)*?)$/',
-  '/^(?:a\\/(?!(?:^|\\/)\\.{1,2}(?:$|\\/))(?=.)[^/]*?\\/b)$/',
-  '/^(?:a\\/(?=.)\\.[^/]*?\\/b)$/',
-  '/^(?:a\\/(?!\\.)(?=.)[^/]*?\\/b)$/',
-  '/^(?:a\\/(?=.)\\.[^/]*?\\/b)$/',
-  '/^(?:(?:(?!(?:\\/|^)(?:\\.{1,2})($|\\/)).)*?)$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?\\(a\\/b\\))$/',
-  '/^(?:(?!\\.)(?=.)(?:a|b)*|(?!\\.)(?=.)(?:a|c)*)$/',
-  '/^(?:(?=.)\\[(?=.)\\!a[^/]*?)$/',
-  '/^(?:(?=.)\\[(?=.)#a[^/]*?)$/',
-  '/^(?:(?=.)\\+\\(a\\|[^/]*?\\|c\\\\\\\\\\|d\\\\\\\\\\|e\\\\\\\\\\\\\\\\\\|f\\\\\\\\\\\\\\\\\\|g)$/',
-  '/^(?:(?!\\.)(?=.)(?:a|b)*|(?!\\.)(?=.)(?:a|c)*)$/',
-  '/^(?:a|(?!\\.)(?=.)[^/]*?\\(b\\|c|d\\))$/',
-  '/^(?:a|(?!\\.)(?=.)(?:b|c)*|(?!\\.)(?=.)(?:b|d)*)$/',
-  '/^(?:(?!\\.)(?=.)(?:a|b|c)*|(?!\\.)(?=.)(?:a|c)*)$/',
-  '/^(?:(?!\\.)(?=.)[^/]*?\\(a\\|b\\|c\\)|(?!\\.)(?=.)[^/]*?\\(a\\|c\\))$/',
-  '/^(?:(?=.)a[^/]b)$/',
-  '/^(?:(?=.)#[^/]*?)$/',
-  '/^(?!^(?:(?=.)a[^/]*?)$).*$/',
-  '/^(?:(?=.)\\!a[^/]*?)$/',
-  '/^(?:(?=.)a[^/]*?)$/',
-  '/^(?!^(?:(?=.)\\!a[^/]*?)$).*$/',
-  '/^(?:(?!\\.)(?=.)[^\\/]*?\\.(?:(?!(?:js)$)[^\\/]*?))$/',
-  '/^(?:(?:(?!(?:\\/|^)\\.).)*?\\/\\.x\\/(?:(?!(?:\\/|^)\\.).)*?)$/',
-  '/^(?:\\[z\\-a\\])$/',
-  '/^(?:a\\/\\[2015\\-03\\-10T00:23:08\\.647Z\\]\\/z)$/',
-  '/^(?:(?=.)\\[a-0\\][a-Ā])$/',
-  false,
-]
-
 Object.defineProperty(module.exports, 'files', {
   get: function () {
     return files
